package icu.fur93.esp32_car.page

import androidx.compose.foundation.layout.Column
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import icu.fur93.esp32_car.Route
import icu.fur93.esp32_car.ui.carditem.StatusCardInfo
import icu.fur93.esp32_car.ui.component.PageTitle
import icu.fur93.esp32_car.ui.theme.LayoutContentModifier
import icu.fur93.esp32_car.viewmodel.CarViewModel
import icu.fur93.esp32_car.ui.carditem.StatusCardInfraredStatus
import icu.fur93.esp32_car.ui.carditem.StatusCardMotorStatus
import icu.fur93.esp32_car.ui.carditem.StatusCardPathfinderStatus
import icu.fur93.esp32_car.ui.component.StatusCard
import icu.fur93.esp32_car.const.RunModeConsts
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import icu.fur93.esp32_car.const.CarCommands
import icu.fur93.esp32_car.ui.carditem.StatusCardUltrasoundStatus

@Composable
fun ControlPathfinderModePage(viewModel: CarViewModel) {

    Column(LayoutContentModifier) {
        PageTitle(Route.ControlPathfinderMode.title)
        ControlPathfinderModeStatusCard(viewModel)
    }
}

@Composable
fun ControlPathfinderModeStatusCard(viewModel: CarViewModel) {
    val deviceInfo by viewModel.connectionInfoState.collectAsState()
    val carState by viewModel.carState.collectAsState()

    StatusCard(
        cardItems = listOf(
            StatusCardInfo(deviceInfo),
            StatusCardMotorStatus(carState),
            StatusCardInfraredStatus(carState.infraredState),
            StatusCardUltrasoundStatus(carState.ultrasoundState),
            StatusCardPathfinderStatus(carState.runModeState)
        ),
        bottomControl = {
            Button(onClick = {
                if (carState.runModeState.runMode == RunModeConsts.MODE_TRACKING) {
                    viewModel.setRunMode(RunModeConsts.MODE_MANUAL.toInt())
                } else {
                    viewModel.setRunMode(RunModeConsts.MODE_TRACKING.toInt())
                }
            }) {
                Text(if (carState.runModeState.runMode == RunModeConsts.MODE_TRACKING) "停止" else "开始")
            }
        }
    )
}